==> free-sa-1.2.1.tar.gz: free-sa-1.2.1/src/reports/r_topuser.c <==
#include "global.h"


int ccueCount = 0;


void ReportTopUser(void) {
    FILE *TUR;
    short int i;
    char stext[128];

    /* TUR: open & header */
    sprintf(stext, "%s (%s)", loc->Bytes, loc->Desc);
    TUR = SAfopenH("../", 'r', loc->TopUser, stext, 1, "w", TEMPL_REPORT, icfg.ReportDir, icfg.TURname);
    
    /* TUR: write table header */
    fprintf(TUR, "\t<tr><td class=el>\n\t<tr><th>%s<th><th>%s<th>%s<th>%s<th>%%%s\n", 
	loc->No, loc->User, loc->Connections, loc->Bytes, loc->Bytes);
    
    /* TUR: sort by bytes (reverse) */
    qsort(Users, (size_t)icfg.ueCount, sizeof(struct SAentry), (int (*)(const void *, const void *))rcompSAentryB);

    /* TUR: write user stats */
    for (i = 0; i < icfg.ueCount; i++) {
	if (Users[i].count) {
	    fprintf(TUR, "\
<tr><td>%d\
<td><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a> <a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>\
<td class=lt><a href=\"u%s.html\">%s</a>\
<td>%'d<td>%'.0f<td>%.2f", 
	    i + 1, 
	    Users[i].name, Users[i].name, Users[i].name, Users[i].vname, 
	    Users[i].count, Users[i].Bytes, Users[i].Bytes/ccBytes*100);
	    IndicsByIndex(TUR, i);
	    
	    ccueCount++;
	} else SAfcloseU(Users[i].file, Users[i].fname); /* close and delete unneeded U_UNS files */
    }
    
    /* TUR: write total and average stats */
    fprintf(TUR, "\
<tr><td colspan=2 class=el><th class=lt>%s<th class=rt>%'d<th class=rt>%'.0f<th class=rt>%.2f\n\
<tr><td colspan=2 class=el><th class=lt>%s<th class=rt>%'d<th class=rt>%'.0f<th class=rt>%.2f\n",
    loc->TOTAL, ccCount, ccBytes, 100.0, 
    loc->AVERAGE, ccCount/ccueCount, ccBytes/ccueCount, 100.0/ccueCount);

    /* TUR: close */
    SAfcloseH(TUR, icfg.TURname);
}

==> free-sa-1.2.4.tar.gz: free-sa-1.2.4/src/reports/r_topuser.c <==
#include "global.h"


int ccueCount = 0;


void ReportTopUser(void) {
    FILE *TUR;
    short int i;
    char stext[128];

    /* TUR: open & header */
    snprintf(stext, sizeof(stext), "%s (%s)", loc->Bytes, loc->Desc);
    TUR = SAfopenH("../", 'r', loc->TopUser, stext, 1, "w", TEMPL_REPORT, icfg.ReportDir, icfg.TURname);
    
    /* TUR: write table header */
    fprintf(TUR, "\t<tr><td class=el>\n\t<tr><th>%s<th><th>%s<th>%s<th>%s<th>%%%s\n", 
	loc->No, loc->User, loc->Connections, loc->Bytes, loc->Bytes);
    
    /* TUR: sort by bytes (reverse) */
    qsort(Users, (size_t)icfg.ueCount, sizeof(struct SAentry), (int (*)(const void *, const void *))rcompSAentryB);

    /* TUR: write user stats */
    for (i = 0; i < icfg.ueCount; i++) {
	if (Users[i].count) {
	    fprintf(TUR, "\
<tr><td>%d\
<td><a href=\"g_%s.html\"><img src=\"../g.png\" alt=\"\"></a> <a href=\"d_%s.html\"><img src=\"../d.png\" alt=\"\"></a>\
<td class=lt><a href=\"u%s.html\">%s</a>\
<td>%'d<td>%'.0f<td>%.2f", 
	    i + 1, 
	    Users[i].name, Users[i].name, Users[i].name, Users[i].vname, 
	    Users[i].count, Users[i].Bytes, Users[i].Bytes/ccBytes*100);
	    IndicsByIndex(TUR, i);
	    
	    ccueCount++;
	} else SAfcloseU(Users[i].file, Users[i].fname); /* close and delete unneeded U_UNS files */
    }
    
    /* TUR: write total and average stats */
    fprintf(TUR, "\
<tr><td colspan=2 class=el><th class=lt>%s<th class=rt>%'d<th class=rt>%'.0f<th class=rt>%.2f\n\
<tr><td colspan=2 class=el><th class=lt>%s<th class=rt>%'d<th class=rt>%'.0f<th class=rt>%.2f\n",
    loc->TOTAL, ccCount, ccBytes, 100.0, 
    loc->AVERAGE, ccCount/ccueCount, ccBytes/ccueCount, 100.0/ccueCount);

    /* TUR: close */
    SAfcloseH(TUR, icfg.TURname);
}
